@@ -3,7 +3,6 @@
 
 module TextRowNew where
 
-import           Control.Applicative
 import           Data.Time.Calendar  (fromGregorian)
 import           Data.Time.LocalTime (LocalTime (..), TimeOfDay (..))
 import           Database.MySQL.Base
@@ -12,7 +11,7 @@ import           Test.Tasty.HUnit
 
 tests :: MySQLConn -> Assertion
 tests c = do
-    (f, is) <- query_ c "SELECT * FROM test_new"
+    (f, is5) <- query_ c "SELECT * FROM test_new"
 
     assertEqual "decode Field types" (columnType <$> f)
         [ mySQLTypeLong
@@ -21,51 +20,51 @@ tests c = do
         , mySQLTypeTime
         ]
 
-    Just v <- Stream.read is
-    assertEqual "decode NULL values" v
+    Just v1 <- Stream.read is5
+    assertEqual "decode NULL values" v1
         [ MySQLInt32 0
         , MySQLNull
         , MySQLNull
         , MySQLNull
         ]
 
-    Stream.skipToEof is
+    Stream.skipToEof is5
 
-    execute_ c "UPDATE test_new SET \
+    _ <- execute_ c "UPDATE test_new SET \
                 \__datetime   = '2016-08-08 17:25:59.12'                  ,\
                 \__timestamp  = '2016-08-08 17:25:59.1234'                ,\
                 \__time       = '-199:59:59.123456' WHERE __id=0"
 
-    (_, is) <- query_ c "SELECT * FROM test_new"
-    Just v <- Stream.read is
+    (_, is4) <- query_ c "SELECT * FROM test_new"
+    Just v2 <- Stream.read is4
 
-    assertEqual "decode text protocol" v
+    assertEqual "decode text protocol" v2
         [ MySQLInt32 0
         , MySQLDateTime (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.12))
         , MySQLTimeStamp (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.1234))
         , MySQLTime 1 (TimeOfDay 199 59 59.123456)
         ]
 
-    Stream.skipToEof is
+    Stream.skipToEof is4
 
-    execute_ c "UPDATE test_new SET \
+    _ <- execute_ c "UPDATE test_new SET \
                 \__datetime   = '2016-08-08 17:25:59.1'                  ,\
                 \__timestamp  = '2016-08-08 17:25:59.12'                ,\
                 \__time       = '199:59:59.1234' WHERE __id=0"
 
-    (_, is) <- query_ c "SELECT * FROM test_new"
-    Just v <- Stream.read is
+    (_, is0) <- query_ c "SELECT * FROM test_new"
+    Just v3 <- Stream.read is0
 
-    assertEqual "decode text protocol 2" v
+    assertEqual "decode text protocol 2" v3
         [ MySQLInt32 0
         , MySQLDateTime (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.1))
         , MySQLTimeStamp (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.12))
         , MySQLTime 0 (TimeOfDay 199 59 59.1234)
         ]
 
-    Stream.skipToEof is
+    Stream.skipToEof is0
 
-    execute c "UPDATE test_new SET \
+    _ <- execute c "UPDATE test_new SET \
             \__datetime   = ?     ,\
             \__timestamp  = ?     ,\
             \__time       = ?  WHERE __id=0"
@@ -75,19 +74,19 @@ tests c = do
                 ]
 
 
-    (_, is) <- query_ c "SELECT * FROM test_new"
-    Just v <- Stream.read is
+    (_, is1) <- query_ c "SELECT * FROM test_new"
+    Just v4 <- Stream.read is1
 
-    assertEqual "roundtrip text protocol" v
+    assertEqual "roundtrip text protocol" v4
         [ MySQLInt32 0
         , MySQLDateTime (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.12))
         , MySQLTimeStamp (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.1234))
         , MySQLTime 1 (TimeOfDay 199 59 59.123456)
         ]
 
-    Stream.skipToEof is
+    Stream.skipToEof is1
 
-    execute c "UPDATE test_new SET \
+    _ <- execute c "UPDATE test_new SET \
             \__datetime   = ?     ,\
             \__timestamp  = ?     ,\
             \__time       = ?  WHERE __id=0"
@@ -96,17 +95,17 @@ tests c = do
                 , MySQLTime 0 (TimeOfDay 199 59 59.1234)
                 ]
 
-    (_, is) <- query_ c "SELECT * FROM test_new"
-    Just v <- Stream.read is
+    (_, is2) <- query_ c "SELECT * FROM test_new"
+    Just v5 <- Stream.read is2
 
-    assertEqual "roundtrip text protocol 2" v
+    assertEqual "roundtrip text protocol 2" v5
         [ MySQLInt32 0
         , MySQLDateTime (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.1))
         , MySQLTimeStamp (LocalTime (fromGregorian 2016 08 08) (TimeOfDay 17 25 59.12))
         , MySQLTime 0 (TimeOfDay 199 59 59.1234)
         ]
 
-    Stream.skipToEof is
+    Stream.skipToEof is2
 
     let row0 =
             [ MySQLInt32 0
@@ -120,13 +119,13 @@ tests c = do
             , MySQLTimeStamp (LocalTime (fromGregorian 2016 08 09) (TimeOfDay 18 25 59.12))
             , MySQLTime 0 (TimeOfDay 299 59 59.1234)
             ]
-    execute c "UPDATE test_new SET \
+    _ <- execute c "UPDATE test_new SET \
             \__id         = ?     ,\
             \__datetime   = ?     ,\
             \__timestamp  = ?     ,\
             \__time       = ?  WHERE __id=0"
             row0
-    execute c "INSERT INTO test_new VALUES(\
+    _ <- execute c "INSERT INTO test_new VALUES(\
             \?,\
             \?,\
             \?,\
@@ -134,13 +133,13 @@ tests c = do
             \)"
             row1
 
-    (_, is) <- query c "SELECT * FROM test_new WHERE __id IN (?) ORDER BY __id" [Many [MySQLInt32 0, MySQLInt32 1]]
-    Just v0 <- Stream.read is
-    Just v1 <- Stream.read is
+    (_, is3) <- query c "SELECT * FROM test_new WHERE __id IN (?) ORDER BY __id" [Many [MySQLInt32 0, MySQLInt32 1]]
+    Just v6 <- Stream.read is3
+    Just v7 <- Stream.read is3
 
-    assertEqual "select list of ids" [v0, v1] [row0, row1]
+    assertEqual "select list of ids" [v6, v7] [row0, row1]
 
-    Stream.skipToEof is
-    execute_ c "DELETE FROM test_new where __id=1"
+    Stream.skipToEof is3
+    _ <- execute_ c "DELETE FROM test_new where __id=1"
 
     return ()
